@@ -145,11 +145,11 @@ class Confluence(AtlassianRestAPI):
             label=label,
             start=start,
             limit=limit)
-        return self.get(url)
+        return (self.get(url) or {}).get('results')
 
     def get_all_pages_from_space(self, space, start=0, limit=500):
         """
-        Get all pages from Space
+        Get all pages from space
         :param space:
         :param start: OPTIONAL: The start point of the collection to return. Default: None (0).
         :param limit: OPTIONAL: The limit of the number of pages to return, this may be restricted by
@@ -223,7 +223,7 @@ class Confluence(AtlassianRestAPI):
 
     def remove_page_from_trash(self, page_id):
         """
-        This method removed page from trash
+        This method removes a page from trash
         :param page_id:
         :return:
         """
@@ -231,19 +231,24 @@ class Confluence(AtlassianRestAPI):
 
     def remove_page_as_draft(self, page_id):
         """
-        This method removed page from trash
+        This method removes a page from trash if it is a draft
         :param page_id:
         :return:
         """
         return self.remove_page(page_id=page_id, status='draft')
 
-    def remove_page(self, page_id, status=None):
+    def remove_page(self, page_id, status=None, recursive=False):
         """
-        This method removed page
+        This method removes a page, if it has recursive flag, method removes including child pages
         :param page_id:
         :param status: OPTIONAL: type of page
+        :param recursive: OPTIONAL: if True - will recursively delete all children pages too
         :return:
         """
+        if recursive:
+            children_pages = self.get_page_child_by_type(page_id)
+            for children_page in children_pages:
+                self.remove_page(children_page.get('id'), status, recursive)
         if status is None:
             url = 'rest/api/content/{page_id}'.format(page_id=page_id)
         else:
@@ -324,6 +329,18 @@ class Confluence(AtlassianRestAPI):
             log.warn("No 'page_id' found, not uploading attachments")
             return None
 
+    def set_page_label(self, page_id, label):
+        """
+        Set a label on the page
+        :param page_id: content_id format
+        :param label: label to add
+        :return:
+        """
+        url = 'rest/api/content/{page_id}/label'.format(page_id=page_id)
+        data = {'prefix': 'global',
+                'name': label}
+        return self.post(path=url, data=data)
+
     def history(self, page_id):
         return self.get('rest/api/content/{0}/history'.format(page_id))
 
@@ -381,7 +398,7 @@ class Confluence(AtlassianRestAPI):
 
     def update_or_create(self, parent_id, title, body):
         """
-        Update page or create page if it is not exists
+        Update page or create a page if it is not exists
         :param parent_id:
         :param title:
         :param body:
@@ -411,6 +428,16 @@ class Confluence(AtlassianRestAPI):
                 'representation': 'wiki'}
         return self.post('rest/api/contentbody/convert/storage', data=data)
 
+    def convert_storage_to_view(self, storage):
+        """
+        Convert from Confluence XHTML format to view format
+        :param storage:
+        :return:
+        """
+        data = {'value': storage,
+                'representation': 'storage'}
+        return self.post('rest/api/contentbody/convert/view', data=data)
+
     def set_page_property(self, page_id, data):
         """
         Set the page (content) property e.g. add hash parameters
@@ -602,3 +629,19 @@ class Confluence(AtlassianRestAPI):
                 page_id = each_page.get("id")
                 break
         return page_id
+
+    def reindex(self):
+        """
+        It is not public method for reindex Confluence
+        :return:
+        """
+        url = 'rest/prototype/1/index/reindex'
+        return self.post(url)
+
+    def reindex_get_status(self):
+        """
+        Get reindex status of Confluence
+        :return:
+        """
+        url = 'rest/prototype/1/index/reindex'
+        return self.get(url)
